@@ -29,7 +29,7 @@ type Size = usize;
 /// assert_eq!(result, expected);
 /// ```
 ///
-/// For further examples see [here](https://github.com/sdsl-rs/sdsl-rs/blob/master/examples/src/wt_int.rs).
+/// For further examples see [here](https://github.com/sdsl-rs/sdsl-rs/blob/master/examples/src/wavelet_trees/wt_int.rs).
 pub struct WtInt<
     'a,
     BitVector = crate::bit_vectors::BitVector,
@@ -104,7 +104,9 @@ where
     /// Construct a wavelet tree from a bit vector.
     /// # Arguments
     /// * `bit_vector` - Bitvector.
-    pub fn from_bit_vector(bit_vector: &crate::interface::bit_vector::BitVector) -> Result<Self> {
+    pub fn from_bit_vector(
+        bit_vector: &crate::interface::bit_vectors::bit_vector::BitVector,
+    ) -> Result<Self> {
         let id = Self::id()?;
         let interface = Interface::new(&id)?;
         let ptr = (interface.from_bit_vector)(*bit_vector.ptr());
